@@ -19,28 +19,12 @@ use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
 use File::Basename;
-use Best [    # Loads the first available module, in order of preference.
-    [
-        'Data::Printer' => {'args' => {'colored' => TRUE, 'use_prototypes' => FALSE}},
-        'Data::Dumper::Simple',
-        'Data::Dumper'
-    ]
-];
-
-our $Modules = {
-    'Data::Printer'        => FALSE,
-    'Data::Dumper::Simple' => FALSE,
-    'Data::Dumper'         => FALSE,
-};
-
-# Now let's set this to whatever module Best loaded.
-$Modules->{Best->which('Data::Printer')} = TRUE;
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.06;
+    our $VERSION = 1.07;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -97,12 +81,15 @@ Debug::Easy - A Handy Debugging Module With Colorized Output and Formatting
  #  DEBUGMAX  = Level 2 Debugging messages (typically more terse)
  #
  # The third parameter is either a string or a reference to an array
- # of strings to output as multiple lines.  If one of the array
- # elements is a reference, then it is passed to the available
- # Data Dumping library.
+ # of strings to output as multiple lines.
  #
  # Each string can contain newlines, which will also be split into
  # a separate line and formatted accordingly.
+ #
+ # NOTICE:  Older versions would use a Data::Dumper library to output
+ # references automatically.  These libraries slow down script
+ # initialization, and thus I removed the capability.  So, if you want
+ # Dumper output, youi must load it yourself and use Dumper in the call
 
  my $debug_level = 'NOTICE';
 
@@ -163,20 +150,6 @@ It is essentially a smart wrapper on top of Log::Fast to enhance it.
  A simple list of all the acceptable debug levels to pass to the {debug} method,
  and the {new} method.
 
-=head2 $Modules
-
- A hash reference indicating which of three data dumping modules it has
- detected and loaded.  The keys are the names of the modules, and the
- value is boolean, either 1 or 0:
-
-=over 1
-
-Data::Printer
-Data::Dumper::Simple
-Data::Dumper
-
-=back
-
 =cut
 
 END {    # We spit out one last message before we die, the total execute time.
@@ -192,36 +165,38 @@ END {    # We spit out one last message before we die, the total execute time.
 
 The parameter names are case insensitive as of Version 0.04.
 
-=over 1
+=over 2
 
 =item B<LogLevel> [level]
 
 This adjusts the global log level of the Debug object.  It requires
 a string.
 
-=over 2
+=back
 
-=item B<ERR> (default)
+=over 4
+
+=item C<ERR> (default)
 
 This level shows only error messages and all other messages are not
 shown.
 
-=item B<WARN>
+=item C<WARN>
 
 This level shows error and warning messages.  All other messages are
 not shown.
 
-=item B<NOTICE>
+=item C<NOTICE>
 
 This level shows error, warning, and notice messages.  All other
 messages are not shown.
 
-=item B<INFO>
+=item C<INFO>
 
 This level shows error, warning, notice, and information messages.
 Only debug level messages are not shown.
 
-=item B<VERBOSE>
+=item C<VERBOSE>
 
 This level can be used as a way to do "Verbose" output for your
 scripts.  It ouputs INFO level messages without logging headers
@@ -232,12 +207,12 @@ simple, I have never run across a script that sent "verbose"
 output on STDERR.  If you don't like this behavior, then just use
 the 'INFO' log level instead of 'VERBOSE'.
 
-=item B<DEBUG>
+=item C<DEBUG>
 
 This level shows error, warning, notice, information, and level 1
 debugging messages.  Level 2 Debug messages are not shown.
 
-=item B<DEBUGMAX>
+=item C<DEBUGMAX>
 
 This level shows all messages up to level 2 debugging messages.
 
@@ -249,17 +224,17 @@ debugging you may not need such a high level of detail.  I use
 'DEBUGMAX' to show me absolutely everything.  Such as Data::Dumper
 output.
 
+=item C<Color> [boolean] (Not case sensitive)
+
 =back
 
-=item B<Color> [boolean] (Not case sensitive)
+=over 6
 
-=over 2
-
-=item B<0>, B<Off>, or B<False> (Off)
+=item C<0>, C<Off>, or C<False> (Off)
 
  This turns off colored output.  Everything is plain text only.
 
-=item B<1>, B<On>, or B<True> (On - Default)
+=item C<1>, C<On>, or C<True> (On - Default)
 
  This turns on colored output.  This makes it easier to spot all of
  the different types of messages throughout a sea of debug output.
@@ -268,7 +243,9 @@ output.
 
 =back
 
-=item B<Prefix> [pattern]
+=over 2
+
+=item C<Prefix> [pattern]
 
 This is global
 
@@ -292,20 +269,20 @@ DEFAULT:  '%Date% %Time% %Benchmark% %Loglevel%[%Subroutine%][%Lastline%] '
      P = Parent
      C = Child
 
-=item B<[loglevel]-Prefix> [pattern]
+=item C<[loglevel]-Prefix> [pattern]
 
 You can define a prefix for a specific log level.
 
-ERR-Prefix
-WARN-Prefix
-NOTICE-Prefix
-INFO-Prefix
-DEBUG-Prefix
-DEBUGMAX-Prefix
+ ERR-Prefix
+ WARN-Prefix
+ NOTICE-Prefix
+ INFO-Prefix
+ DEBUG-Prefix
+ DEBUGMAX-Prefix
 
 If one of these are not defined, then the global value is used.
 
-=item B<TimeStamp> [pattern]
+=item C<TimeStamp> [pattern]
 
 (See Log::Fast for specifics on these)
 
@@ -313,25 +290,29 @@ I suggest you just use Prefix above, but here it is anyway.
 
 Make this an empty string to turn it off, otherwise:
 
-=over 2
+=back
 
-=item B<%T>
+=over 4
+
+=item C<%T>
 
  Formats the timestamp as HH:MM:SS.  This is the default for the
  timestamp.
 
-=item B<%S>
+=item C<%S>
 
  Formats the timestamp as seconds.milliseconds.  Normally not needed,
  as the benchmark is more helpful.
 
-=item B<%T %S>
+=item C<%T %S>
 
  Combines both of the above.  Normally this is just too much, but here
  if you really want it.
 
 =back
 
+=over 2
+
 =item B<DateStamp> [pattern]
 
 I suggest you just use Prefix above, but here it is anyway.
@@ -340,34 +321,42 @@ I suggest you just use Prefix above, but here it is anyway.
 
 Make this an empty string to turn it off, otherwise:
 
-=over 2
+=back
 
-=item B<%D>
+=over 4
+
+=item C<%D>
 
  Formats the datestamp as YYYY-MM-DD.  It is the default, and the only
  option.
 
 =back
 
+=over 2
+
 =item B<Type>
 
  Output type. Possible values are: 'fh' (output to any already open
  filehandle) and 'unix' (output to syslog using UNIX socket).
 
-=over 2
+=back
 
-=item B<fh>
+=over 4
+
+=item C<fh>
 
  When set to 'fh', you have to also set {FileHandle} to any open filehandle
  (like "\*STDERR", which is the default).
 
-=item B<unix>
+=item C<unix>
 
  When set to 'unix', you have to also set {FileHandle} to a path pointing to an
  existing unix socket (typically it's '/dev/log').
 
 =back
 
+=over 2
+
 =item B<FileHandle>
 
  File handle to write log messages if {Type} set to 'fh' (which is the default).
@@ -380,7 +369,9 @@ Make this an empty string to turn it off, otherwise:
 
  The default definition (using Term::ANSIColor) is as follows:
 
-=over 2
+=back
+
+=over 4
 
   'ANSILevel' => {
      'ERR'       => colored(['white on_red'],       '[ ERROR ]'),
@@ -392,8 +383,6 @@ Make this an empty string to turn it off, otherwise:
   }
 
 
-=back
-
 =back
 
 =cut
@@ -497,7 +486,7 @@ sub new {
     # Signal the script has started (and logger initialized)
     my $name = $SCRIPTNAME;
     $name .= ' [child]' if ($PARENT ne $$);
-    $self->{'LOG'}->DEBUG('   %.02f%s %s', 0, $self->{'ANSILEVEL'}->{'DEBUG'}, colored(['black on_white'], "----- $name begin -----"));
+    $self->{'LOG'}->DEBUG('   %.02f%s %s', 0, $self->{'ANSILEVEL'}->{'DEBUG'}, colored(['black on_white'], "----- $name begin -----") . " (To View in 'less', use it's '-r' switch)" );
     bless($self, $class);
     return ($self);
 } ## end sub new
@@ -506,15 +495,15 @@ sub new {
 
 The parameters must be passed in the order given
 
-=over 1
+=over 2
 
-=item B<LEVEL>
+=item C<LEVEL>
 
  The log level with which this message is to be triggered
 
-=item B<MESSAGE(S)>
+=item C<MESSAGE(S)>
 
- A string or list of strings to output line by line.
+ A string or a reference to a list of strings to output line by line.
 
 =back
 
@@ -542,11 +531,7 @@ sub debug {
     } elsif (ref($msgs) eq 'ARRAY') {
         @messages = @{$msgs};
     } else {
-        if ($Modules->{'Data::Printer'}) {
-            eval {push(@messages, p($msgs));};
-        } else {
-            eval {push(@messages, Dumper($msgs));};
-        }
+        push(@messages,'** Not a scalar or array reference!  Debug::Easy no longer supports generating Data::Dumper output.  You must do this yourself, and then sent the output to Debug::Easy **');
     } ## end else [ if (ref($msgs) eq 'SCALAR'...)]
     my ($sname, $cline, $nested, $subroutine, $thisBench, $thisBench2, $sline, $short) = ('', '', '', '', '', '', '', '');
 
@@ -613,11 +598,7 @@ sub debug {
     my $first = TRUE;    # Set the first line flag.
     foreach my $msg (@messages) {    # Loop through each line of output and format accordingly.
         if (ref($msg) ne '') {
-            if ($Modules->{'Data::Printer'}) {
-                eval {$msg = p($msg);};
-            } else {
-                eval {$msg = Dumper($msg);};
-            }
+            $msg = '** Not a scalar or array reference!  Debug::Easy no longer supports generating Data::Dumper output.  You must do this yourself, and then sent the output to Debug::Easy **';
         } ## end if (ref($msg) ne '')
         if ($msg =~ /\n/s) {         # If the line contains newlines, then it too must be split into multiple lines.
             my @message = split(/\n/, $msg);
@@ -685,11 +666,12 @@ sub _send_to_logger {      # This actually simplifies the previous object ... se
 
 =head2 ERR
 
-This is a friendlier wrapper to 'debug('ERR',['message'])'.  The level is inferred by its name.
+This is a friendlier wrapper to 'debug('ERR',['message'])'.  The level is
+inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -705,9 +687,9 @@ sub ERR {
 
 This is a friendlier wrapper to 'debug('ERR',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -723,9 +705,9 @@ sub ERROR {
 
 This is a friendlier wrapper to 'debug('WARN',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -741,9 +723,9 @@ sub WARN {
 
 This is a friendlier wrapper to 'debug('WARN',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -759,9 +741,9 @@ sub WARNING {
 
 This is a friendlier wrapper to 'debug('NOTICE',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -777,9 +759,9 @@ sub NOTICE {
 
 This is a friendlier wrapper to 'debug('INFO',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -795,9 +777,9 @@ sub INFO {
 
 This is a friendlier wrapper to 'debug('INFO',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -813,9 +795,9 @@ sub INFORMATION {
 
 This is a friendlier wrapper to 'debug('DEBUG',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -831,9 +813,9 @@ sub DEBUG {
 
 This is a friendlier wrapper to 'debug('DEBUGMAX',['message'])'.  The level is inferred by its name.
 
-=over 1
+=over 2
 
-=item B<MESSAGE>
+=item C<MESSAGE>
 
 Either a single string or a reference to a list of strings
 
@@ -883,7 +865,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 1.06    (July 27, 2015)
+Version 1.07    (September 04, 2015)
 
 =head1 BUGS
 
